diff --git a/ASLUAV/version.h b/ASLUAV/version.h
index 4a29c4a8f..2ecda8328 100644
--- a/ASLUAV/version.h
+++ b/ASLUAV/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/ardupilotmega/version.h b/ardupilotmega/version.h
index dbdd2b921..a4c4dd9a5 100644
--- a/ardupilotmega/version.h
+++ b/ardupilotmega/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/autoquad/version.h b/autoquad/version.h
index 0e53ae0d7..2d12f3b0f 100644
--- a/autoquad/version.h
+++ b/autoquad/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/common/version.h b/common/version.h
index ced40db4d..9bdaefae3 100644
--- a/common/version.h
+++ b/common/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/icarous/version.h b/icarous/version.h
index 2f197604a..12894f72b 100644
--- a/icarous/version.h
+++ b/icarous/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 46
diff --git a/matrixpilot/version.h b/matrixpilot/version.h
index 643f4a510..a0032c34e 100644
--- a/matrixpilot/version.h
+++ b/matrixpilot/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/message_definitions/common.xml b/message_definitions/common.xml
index bc0ea8e6c..7c554e8e5 100644
--- a/message_definitions/common.xml
+++ b/message_definitions/common.xml
@@ -211,8 +211,8 @@
0x20000000 Avoidance/collision prevention
-
- 0x40000000 porpulsion (actuator, esc, motor or propellor)
+
+ 0x40000000 propulsion (actuator, esc, motor or propellor)
diff --git a/minimal/version.h b/minimal/version.h
index 6a324cdc1..a9e0b925d 100644
--- a/minimal/version.h
+++ b/minimal/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 22
diff --git a/standard/version.h b/standard/version.h
index 8c945f069..fa06a6da3 100644
--- a/standard/version.h
+++ b/standard/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/test/version.h b/test/version.h
index 4811b91e0..1fd357eaa 100644
--- a/test/version.h
+++ b/test/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 179
diff --git a/uAvionix/version.h b/uAvionix/version.h
index d9b0f3d31..5531889ad 100644
--- a/uAvionix/version.h
+++ b/uAvionix/version.h
@@ -7,7 +7,7 @@
#ifndef MAVLINK_VERSION_H
#define MAVLINK_VERSION_H
-#define MAVLINK_BUILD_DATE "Mon Feb 15 2021"
+#define MAVLINK_BUILD_DATE "Tue Feb 16 2021"
#define MAVLINK_WIRE_PROTOCOL_VERSION "2.0"
#define MAVLINK_MAX_DIALECT_PAYLOAD_SIZE 255
diff --git a/common/common.h b/common/common.h
index e0eb0b897..da29ddd90 100644
--- a/common/common.h
+++ b/common/common.h
@@ -140,7 +140,7 @@ typedef enum MAV_SYS_STATUS_SENSOR
MAV_SYS_STATUS_SENSOR_SATCOM=134217728, /* 0x8000000 Satellite Communication | */
MAV_SYS_STATUS_PREARM_CHECK=268435456, /* 0x10000000 pre-arm check status. Always healthy when armed | */
MAV_SYS_STATUS_OBSTACLE_AVOIDANCE=536870912, /* 0x20000000 Avoidance/collision prevention | */
- MAV_SYS_STATUS_SENSOR_PORPULSION=1073741824, /* 0x40000000 porpulsion (actuator, esc, motor or propellor) | */
+ MAV_SYS_STATUS_SENSOR_PROPULSION=1073741824, /* 0x40000000 propulsion (actuator, esc, motor or propellor) | */
MAV_SYS_STATUS_SENSOR_ENUM_END=1073741825, /* | */
} MAV_SYS_STATUS_SENSOR;
#endif